@@ -1348,6 +1348,49 @@ class CfnDomainOptions:
         )
 
 
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/core.CfnNagSuppressRule",
+    jsii_struct_bases=[],
+    name_mapping={"id": "id", "reason": "reason"},
+)
+class CfnNagSuppressRule:
+    def __init__(self, *, id: builtins.str, reason: builtins.str) -> None:
+        '''The CFN NAG suppress rule interface.
+
+        :param id: -
+        :param reason: -
+
+        :interface: CfnNagSuppressRule
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "id": id,
+            "reason": reason,
+        }
+
+    @builtins.property
+    def id(self) -> builtins.str:
+        result = self._values.get("id")
+        assert result is not None, "Required property 'id' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def reason(self) -> builtins.str:
+        result = self._values.get("reason")
+        assert result is not None, "Required property 'reason' is missing"
+        return typing.cast(builtins.str, result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "CfnNagSuppressRule(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/core.CognitoOptions",
     jsii_struct_bases=[],
@@ -1652,6 +1695,7 @@ class SinkStoreType(enum.Enum):
         "encryption_key": "encryptionKey",
         "encryption_key_props": "encryptionKeyProps",
         "endpoint_props": "endpointProps",
+        "existing_bucket_interface": "existingBucketInterface",
         "existing_bucket_obj": "existingBucketObj",
         "existing_glue_job": "existingGlueJob",
         "existing_lambda_obj": "existingLambdaObj",
@@ -1660,6 +1704,7 @@ class SinkStoreType(enum.Enum):
         "existing_sagemaker_endpoint_obj": "existingSagemakerEndpointObj",
         "existing_secret_obj": "existingSecretObj",
         "existing_stream_obj": "existingStreamObj",
+        "existing_table_interface": "existingTableInterface",
         "existing_table_obj": "existingTableObj",
         "existing_topic_obj": "existingTopicObj",
         "existing_vpc": "existingVpc",
@@ -1685,6 +1730,7 @@ class VerifiedProps:
         encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
         encryption_key_props: typing.Optional[aws_cdk.aws_kms.KeyProps] = None,
         endpoint_props: typing.Optional[aws_cdk.aws_sagemaker.CfnEndpointProps] = None,
+        existing_bucket_interface: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
         existing_glue_job: typing.Optional[aws_cdk.aws_glue.CfnJob] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
@@ -1693,6 +1739,7 @@ class VerifiedProps:
         existing_sagemaker_endpoint_obj: typing.Optional[aws_cdk.aws_sagemaker.CfnEndpoint] = None,
         existing_secret_obj: typing.Optional[aws_cdk.aws_secretsmanager.Secret] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
+        existing_table_interface: typing.Optional[aws_cdk.aws_dynamodb.ITable] = None,
         existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
         existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
@@ -1714,6 +1761,7 @@ class VerifiedProps:
         :param encryption_key: -
         :param encryption_key_props: -
         :param endpoint_props: -
+        :param existing_bucket_interface: -
         :param existing_bucket_obj: -
         :param existing_glue_job: -
         :param existing_lambda_obj: -
@@ -1722,6 +1770,7 @@ class VerifiedProps:
         :param existing_sagemaker_endpoint_obj: -
         :param existing_secret_obj: -
         :param existing_stream_obj: -
+        :param existing_table_interface: -
         :param existing_table_obj: -
         :param existing_topic_obj: -
         :param existing_vpc: -
@@ -1777,6 +1826,8 @@ class VerifiedProps:
             self._values["encryption_key_props"] = encryption_key_props
         if endpoint_props is not None:
             self._values["endpoint_props"] = endpoint_props
+        if existing_bucket_interface is not None:
+            self._values["existing_bucket_interface"] = existing_bucket_interface
         if existing_bucket_obj is not None:
             self._values["existing_bucket_obj"] = existing_bucket_obj
         if existing_glue_job is not None:
@@ -1793,6 +1844,8 @@ class VerifiedProps:
             self._values["existing_secret_obj"] = existing_secret_obj
         if existing_stream_obj is not None:
             self._values["existing_stream_obj"] = existing_stream_obj
+        if existing_table_interface is not None:
+            self._values["existing_table_interface"] = existing_table_interface
         if existing_table_obj is not None:
             self._values["existing_table_obj"] = existing_table_obj
         if existing_topic_obj is not None:
@@ -1856,6 +1909,11 @@ class VerifiedProps:
         result = self._values.get("endpoint_props")
         return typing.cast(typing.Optional[aws_cdk.aws_sagemaker.CfnEndpointProps], result)
 
+    @builtins.property
+    def existing_bucket_interface(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
+        result = self._values.get("existing_bucket_interface")
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.IBucket], result)
+
     @builtins.property
     def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         result = self._values.get("existing_bucket_obj")
@@ -1900,6 +1958,11 @@ class VerifiedProps:
         result = self._values.get("existing_stream_obj")
         return typing.cast(typing.Optional[aws_cdk.aws_kinesis.Stream], result)
 
+    @builtins.property
+    def existing_table_interface(self) -> typing.Optional[aws_cdk.aws_dynamodb.ITable]:
+        result = self._values.get("existing_table_interface")
+        return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.ITable], result)
+
     @builtins.property
     def existing_table_obj(self) -> typing.Optional[aws_cdk.aws_dynamodb.Table]:
         result = self._values.get("existing_table_obj")
@@ -1987,6 +2050,7 @@ __all__ = [
     "BuildTopicProps",
     "BuildVpcProps",
     "CfnDomainOptions",
+    "CfnNagSuppressRule",
     "CognitoOptions",
     "EventSourceProps",
     "SecurityGroupRuleDefinition",
